==> zio-aws-mediapackage_2.13-5.17.125.1-sources.jar: zio/aws/mediapackage/model/DescribeChannelRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeChannelRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest = {
    import DescribeChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest
      .builder()
      .id(__string.unwrap(id): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediapackage.model.DescribeChannelRequest.ReadOnly =
    zio.aws.mediapackage.model.DescribeChannelRequest.wrap(buildAwsValue())
}
object DescribeChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.DescribeChannelRequest =
      zio.aws.mediapackage.model.DescribeChannelRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest
  ) extends zio.aws.mediapackage.model.DescribeChannelRequest.ReadOnly {
    override val id: __string =
      zio.aws.mediapackage.model.primitives.__string(impl.id())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest
  ): zio.aws.mediapackage.model.DescribeChannelRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediapackage_2.13-5.17.295.11-sources.jar: zio/aws/mediapackage/model/DescribeChannelRequest.scala <==
package zio.aws.mediapackage.model
import zio.aws.mediapackage.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeChannelRequest(id: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest = {
    import DescribeChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest
      .builder()
      .id(id: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediapackage.model.DescribeChannelRequest.ReadOnly =
    zio.aws.mediapackage.model.DescribeChannelRequest.wrap(buildAwsValue())
}
object DescribeChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediapackage.model.DescribeChannelRequest =
      zio.aws.mediapackage.model.DescribeChannelRequest(id)
    def id: __string
    def getId: ZIO[Any, Nothing, __string] = ZIO.succeed(id)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest
  ) extends zio.aws.mediapackage.model.DescribeChannelRequest.ReadOnly {
    override val id: __string = impl.id(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediapackage.model.DescribeChannelRequest
  ): zio.aws.mediapackage.model.DescribeChannelRequest.ReadOnly = new Wrapper(
    impl
  )
}
